<?php

namespace Drupal\Tests\drowl_admin\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * This class provides methods specifically for testing something.
 *
 * @group drowl_admin
 */
class DrowlAdminFunctionalTest extends BrowserTestBase {
  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'drowl_admin',
    'test_page_test',
    'admin_toolbar',
    'layout_builder',
  ];

  /**
   * A user with authenticated permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $user;

  /**
   * A user with admin permissions.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->config('system.site')->set('page.front', '/test-page')->save();
    $this->user = $this->drupalCreateUser([]);
    $this->adminUser = $this->drupalCreateUser([]);
    $this->adminUser->addRole($this->createAdminRole('admin', 'admin'));
    $this->adminUser->save();
    $this->drupalLogin($this->adminUser);
  }

  /**
   * Tests if the module installation, won't break the site.
   */
  public function testInstallation() {
    $session = $this->assertSession();
    $this->drupalGet('<front>');
    $session->statusCodeEquals(200);
  }

  /**
   * Tests to see if the libraries are loaded on the admin site.
   */
  public function testLibrariesAvailable() {
    $session = $this->assertSession();
    $this->drupalGet('/admin');
    $session->statusCodeEquals(200);
    $session->elementExists('css', 'head > link[href*="drowl_admin.variables"]');
    $session->elementExists('css', 'head > link[href*="drowl_admin.toolbar_fixes"]');
    // @todo Can not check ckeditor_tweaks, since for some reason "/admin" is
    // NOT an admin route in the test environment, maybe a module is missing?
    // See:
    // $isAdminRoute = \Drupal::service('router.admin_context')->isAdminRoute('/admin');
    // $this->assertEquals('asdfasdf', $isAdminRoute);
    // $session->elementExists('css', 'head > link[href*="drowl_admin.ckeditor_tweaks"]');
  }

}
